# Shuffle-based

## Random shuffle (RS)

Randomly shuffled surrogates are simply permutations of the original time series.

Thus, they break any correlations in the signal.

```@example
using TimeseriesSurrogates, Plots
x = AR1() # create a realization of a random AR(1) process
phases = true
s = surrogate(x, RandomShuffle())

surroplot(x, s)
```

## Block shuffle (BS)

Randomly shuffled surrogates are generated by dividing the original signal into
blocks, then permuting those blocks. Block positions are randomized, and
blocks at the end of the signal gets wrapped around to the start of the time
series.

Thus, they keep short-term correlations within
blocks, but destroy any long-term dynamical information in the signal.

```@example
using TimeseriesSurrogates, Plots
x = NSAR2(n_steps = 300)

# We want to divide the signal into 8 blocks.
s = surrogate(x, BlockShuffle(8))
p = surroplot(x, s)
savefig(p, "../surroplot.png") # hide
p
```
